@@ -1,22 +1,32 @@
 package Evo;
 use Evo::Base -strict;
 use Evo::Manager;
+use Evo::Messenger;
 
 use Exporter 'import';
 
+my @MSN  = qw(msn_subscribe msn_broadcast msn_unsubscribe);
 my @DSL  = qw(dsl_stash dsl_check_stash dsl_call dsl_depth);
 my @FUNC = qw(asap);
-our @EXPORT_OK = (@DSL, @FUNC);
-our %EXPORT_TAGS = (all => \@EXPORT_OK, dsl => \@DSL);
+our @EXPORT_OK = (@DSL, @FUNC, @MSN);
+our %EXPORT_TAGS
+  = (all => \@EXPORT_OK, dsl => \@DSL, msn => \@MSN, func => \@FUNC);
 
-our $VERSION = '0.015';    # VERSION
+our $VERSION = '0.0152';    # VERSION
+
+sub asap : prototype(&@) { Evo::Manager->singleton->asap(@_) }
 
-sub asap : prototype(&@)            { Evo::Manager->singleton->asap(@_) }
 sub dsl_depth : prototype()         { Evo::Manager->singleton->dsl_depth; }
 sub dsl_call : prototype($;@)       { Evo::Manager->singleton->dsl_call(@_); }
 sub dsl_stash : prototype(;$$)      { Evo::Manager->singleton->dsl_stash(@_); }
 sub dsl_check_stash : prototype(;$) { Evo::Manager->singleton->dsl_stash(@_); }
 
+sub _msn { state $msn = Evo::Messenger->new }
+sub msn_broadcast : prototype($$)   { _msn->broadcast(@_); }
+sub msn_subscribe : prototype($$)   { _msn->subscribe(@_); }
+sub msn_unsubscribe : prototype($$) { _msn->unsubscribe(@_); }
+
+
 1;
 
 # ABSTRACT: Perl Evo design pattern
@@ -33,31 +43,34 @@ Evo - Perl Evo design pattern
 
 =head1 VERSION
 
-version 0.015
+version 0.0152
 
 =head1 SYNOPSIS
 
   use Evo::Base -strict;
-  use Evo;
+  use Evo ':all';
 
-  use Evo::Manager;
-  my $mngr = Evo::Manager->new;
 
   # next tick
   our $state = 'non blocking';
 
   # always nb
-  Evo::asap {
+  asap {
     say $state;
     local $state = 'blocking?';
-    Evo::asap { say $state };
+    asap { say $state };
   };
 
+
   # dsl
   # prints 1;2;foo
   my @args = (1, 2);
-  my $print = sub(@args) { local $, = ';'; say @args, $mngr->dsl_stash('foo') };
-  $mngr->dsl_call({foo => 'foo'}, @args, $print);
+  my $print = sub(@args) { local $, = ';'; say @args, dsl_stash 'foo' };
+
+  dsl_call({foo => 'foo'}, @args, $print);
+
+  require Evo::Manager;
+  my $mngr = Evo::Manager->new;
 
   # currying
   my $debug = sub($evo, $next) {
@@ -103,6 +116,11 @@ version 0.015
 
 =head1 METHODS
 
+=head2 msn_broadcast, msn_subscribe, msn_unsubscribe
+
+Calls corresponding L<Evo::Messenger> methods passing a singleton as the first
+argument
+
 =head2 asap, dsl_depth, dsl_stash dsl_check_stash dsl_call dsl_depth
 
 Calls corresponding L<Evo::Manager> methods passing a singleton as the first
